#function ohne arga get_color


def get_colors():
    
        custom_colors ={
                'cpsme_blue_4'           : '#1D3557',
                'cpsme_red'             : '#E63946',
                'cpsme_black'           : '#323232',
                'cpsme_white'           : '#FAFAFA',
                'cpsme_green'           : '#00b695',
                'cpsme_blue_2'           : '#008b9a',
                'cpsme_blue_3'           : '#457B9D',
                'cpsme_blue_1'           : '#A8DADC',
                'cpsme_grey_4'           : '#646464',
                'cpsme_grey_1'           : '#E1E1E1',
                'cpsme_grey_2'           : '#C8C8C8',
                'cpsme_grey_3'           : '#969696',
                'cpsme_mint_green'      : '#F1FAEE'
        }

        return custom_colors